@@ -1,10 +1,9 @@
-#include "fallback/begin_implementation.h"
-#include "fallback/dom_parser_implementation.h"
+#include "simdjson/fallback/begin.h"
 
-namespace {
+namespace simdjson {
 namespace SIMDJSON_IMPLEMENTATION {
 
-SIMDJSON_WARN_UNUSED error_code implementation::create_dom_parser_implementation(
+simdjson_warn_unused error_code implementation::create_dom_parser_implementation(
   size_t capacity,
   size_t max_depth,
   std::unique_ptr<internal::dom_parser_implementation>& dst
@@ -17,6 +16,6 @@ SIMDJSON_WARN_UNUSED error_code implementation::create_dom_parser_implementation
 }
 
 } // namespace SIMDJSON_IMPLEMENTATION
-} // unnamed namespace
+} // namespace simdjson
 
-#include "fallback/end_implementation.h"
\ No newline at end of file
+#include "simdjson/fallback/end.h"
\ No newline at end of file
