@@ -23,6 +23,9 @@ const westmere::implementation westmere_singleton{};
 #if SIMDJSON_IMPLEMENTATION_ARM64
 const arm64::implementation arm64_singleton{};
 #endif // SIMDJSON_IMPLEMENTATION_ARM64
+#if SIMDJSON_IMPLEMENTATION_PPC64
+const ppc64::implementation ppc64_singleton{};
+#endif // SIMDJSON_IMPLEMENTATION_PPC64
 #if SIMDJSON_IMPLEMENTATION_FALLBACK
 const fallback::implementation fallback_singleton{};
 #endif // SIMDJSON_IMPLEMENTATION_FALLBACK
@@ -65,6 +68,9 @@ const std::initializer_list<const implementation *> available_implementation_poi
 #if SIMDJSON_IMPLEMENTATION_ARM64
   &arm64_singleton,
 #endif
+#if SIMDJSON_IMPLEMENTATION_PPC64
+  &ppc64_singleton,
+#endif
 #if SIMDJSON_IMPLEMENTATION_FALLBACK
   &fallback_singleton,
 #endif
